Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(162)

Unified Diff: src/default_policy_unittest.cc

Issue 5180003: cashew: add local byte counters (Closed) Base URL: ssh://git@gitrw.chromium.org:9222/cashew.git@master
Patch Set: Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/default_policy.cc ('k') | src/device.h » ('j') | src/device.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/default_policy_unittest.cc
diff --git a/src/default_policy_unittest.cc b/src/default_policy_unittest.cc
index b616d0a4129f2c3fda587d5fd15b5925e6717118..feaa1f1d4d09d9f47dbdea4fceb0119fa6d8135d 100644
--- a/src/default_policy_unittest.cc
+++ b/src/default_policy_unittest.cc
@@ -15,7 +15,6 @@ class DefaultPolicyTest: public ::testing::Test {
virtual ~DefaultPolicyTest() {
EXPECT_TRUE(policy_ == NULL);
- EXPECT_TRUE(old_plans_.empty());
EXPECT_TRUE(plans_.empty());
}
@@ -33,26 +32,21 @@ class DefaultPolicyTest: public ::testing::Test {
static const char *kTestCarrierName;
DefaultPolicy *policy_;
- DataPlanList old_plans_;
DataPlanList plans_;
};
const char *DefaultPolicyTest::kTestCarrierName = "Test Carrier";
TEST_F(DefaultPolicyTest, GetUpdateTimerIdleSecs) {
// we expect the default timer value to be 10 mins = 600 secs
// unconditionally (i.e., independent of value of |plans_|) for now
- EXPECT_EQ(600, policy_->GetUpdateTimerIdleSecs(plans_));
+ EXPECT_EQ(60, policy_->GetUpdateTimerIdleSecs(plans_));
}
TEST_F(DefaultPolicyTest, ShouldEmitDataPlansUpdate) {
// we expect the result to be true unconditionally (i.e., independent of the
- // values of |old_plans_| and |plans_|) for now
- EXPECT_TRUE(policy_->ShouldEmitDataPlansUpdate(old_plans_, plans_));
-}
-
-TEST_F(DefaultPolicyTest, UsageRequestsMustBeSentOTA) {
- EXPECT_TRUE(policy_->UsageRequestsMustBeSentOTA());
+ // value of |plans_|) for now
+ EXPECT_TRUE(policy_->ShouldEmitDataPlansUpdate(plans_));
}
TEST_F(DefaultPolicyTest, ZonelessTimeStringsAreLocal) {
« no previous file with comments | « src/default_policy.cc ('k') | src/device.h » ('j') | src/device.cc » ('J')
@@ -33,26 +32,21 @@ class DefaultPolicyTest: public ::testing::Test {
const char *DefaultPolicyTest::kTestCarrierName = "Test Carrier";
TEST_F(DefaultPolicyTest, GetUpdateTimerIdleSecs) {
- // we expect the default timer value to be 10 mins = 600 secs
+ // we expect the default timer value to be 1 min = 60 secs
// unconditionally (i.e., independent of value of |plans_|) for now

Powered by Google App Engine
This is Rietveld 408576698